@@ -38,7 +38,7 @@ public:
     KScreen::ConfigPtr config() const Q_DECL_OVERRIDE;
 
 protected:
-    void start();
+    void start() Q_DECL_OVERRIDE;
 
 private:
     Q_DECLARE_PRIVATE(SetConfigOperation)
